pepys\_import.file package
==========================

Submodules
----------

pepys\_import.file.core\_parser module
--------------------------------------

.. automodule:: pepys_import.file.core_parser
   :members:
   :undoc-members:
   :show-inheritance:

pepys\_import.file.file\_processor module
-----------------------------------------

.. automodule:: pepys_import.file.file_processor
   :members:
   :undoc-members:
   :show-inheritance:

pepys\_import.file.sample\_parser module
----------------------------------------

.. automodule:: pepys_import.file.sample_parser
   :members:
   :undoc-members:
   :show-inheritance:


Module contents
---------------

.. automodule:: pepys_import.file
   :members:
   :undoc-members:
   :show-inheritance:
